#define LOOKUP_TABLE_LEN (sizeof(lookup_table) / (2 * sizeof(double)))
static const struct hp_t lookup_table[] = {
	{ 1.000000e+308,	-1.097906362944045488e+291 },
	{ 1.000000e+307,	1.396894023974354241e+290 },
	{ 1.000000e+306,	-1.721606459673645508e+289 },
	{ 1.000000e+305,	6.074644749446353973e+288 },
	{ 1.000000e+304,	6.074644749446353567e+287 },
	{ 1.000000e+303,	-1.617650767864564452e+284 },
	{ 1.000000e+302,	-7.629703079084895055e+285 },
	{ 1.000000e+301,	-5.250476025520442286e+284 },
	{ 1.000000e+300,	-5.250476025520441956e+283 },
	{ 1.000000e+299,	-5.250476025520441750e+282 },
	{ 1.000000e+298,	4.043379652465702264e+281 },
	{ 1.000000e+297,	-1.765280146275637946e+280 },
	{ 1.000000e+296,	1.865132227937699609e+279 },
	{ 1.000000e+295,	1.865132227937699609e+278 },
	{ 1.000000e+294,	-6.643646774124810287e+277 },
	{ 1.000000e+293,	7.537651562646039934e+276 },
	{ 1.000000e+292,	-1.325659897835741608e+275 },
	{ 1.000000e+291,	4.213909764965371606e+274 },
	{ 1.000000e+290,	-6.172783352786715670e+273 },
	{ 1.000000e+289,	-6.172783352786715670e+272 },
	{ 1.000000e+288,	-7.630473539575035471e+270 },
	{ 1.000000e+287,	-7.525217352494018700e+270 },
	{ 1.000000e+286,	-3.298861103408696612e+269 },
	{ 1.000000e+285,	1.984084207947955778e+268 },
	{ 1.000000e+284,	-7.921438250845767591e+267 },
	{ 1.000000e+283,	4.460464822646386735e+266 },
	{ 1.000000e+282,	-3.278224598286209647e+265 },
	{ 1.000000e+281,	-3.278224598286209737e+264 },
	{ 1.000000e+280,	-3.278224598286209961e+263 },
	{ 1.000000e+279,	-5.797329227496039232e+262 },
	{ 1.000000e+278,	3.649313132040821498e+261 },
	{ 1.000000e+277,	-2.867878510995372374e+259 },
	{ 1.000000e+276,	-5.206914080024985409e+259 },
	{ 1.000000e+275,	4.018322599210230404e+258 },
	{ 1.000000e+274,	7.862171215558236495e+257 },
	{ 1.000000e+273,	5.459765830340732821e+256 },
	{ 1.000000e+272,	-6.552261095746788047e+255 },
	{ 1.000000e+271,	4.709014147460262298e+254 },
	{ 1.000000e+270,	-4.675381888545612729e+253 },
	{ 1.000000e+269,	-4.675381888545612892e+252 },
	{ 1.000000e+268,	2.656177514583977380e+251 },
	{ 1.000000e+267,	2.656177514583977190e+250 },
	{ 1.000000e+266,	-3.071603269111014892e+249 },
	{ 1.000000e+265,	-6.651466258920385440e+248 },
	{ 1.000000e+264,	-4.414051890289528972e+247 },
	{ 1.000000e+263,	-1.617283929500958387e+246 },
	{ 1.000000e+262,	-1.617283929500958241e+245 },
	{ 1.000000e+261,	7.122615947963323868e+244 },
	{ 1.000000e+260,	-6.533477610574617382e+243 },
	{ 1.000000e+259,	7.122615947963323982e+242 },
	{ 1.000000e+258,	-5.679971763165996225e+241 },
	{ 1.000000e+257,	-3.012765990014054219e+240 },
	{ 1.000000e+256,	-3.012765990014054219e+239 },
	{ 1.000000e+255,	1.154743030535854616e+238 },
	{ 1.000000e+254,	6.364129306223240767e+237 },
	{ 1.000000e+253,	6.364129306223241129e+236 },
	{ 1.000000e+252,	-9.915202805299840595e+235 },
	{ 1.000000e+251,	-4.827911520448877980e+234 },
	{ 1.000000e+250,	7.890316691678530146e+233 },
	{ 1.000000e+249,	7.890316691678529484e+232 },
	{ 1.000000e+248,	-4.529828046727141859e+231 },
	{ 1.000000e+247,	4.785280507077111924e+230 },
	{ 1.000000e+246,	-6.858605185178205305e+229 },
	{ 1.000000e+245,	-4.432795665958347728e+228 },
	{ 1.000000e+244,	-7.465057564983169531e+227 },
	{ 1.000000e+243,	-7.465057564983169741e+226 },
	{ 1.000000e+242,	-5.096102956370027445e+225 },
	{ 1.000000e+241,	-5.096102956370026952e+224 },
	{ 1.000000e+240,	-1.394611380411992474e+223 },
	{ 1.000000e+239,	9.188208545617793960e+221 },
	{ 1.000000e+238,	-4.864759732872650359e+221 },
	{ 1.000000e+237,	5.979453868566904629e+220 },
	{ 1.000000e+236,	-5.316601966265964857e+219 },
	{ 1.000000e+235,	-5.316601966265964701e+218 },
	{ 1.000000e+234,	-1.786584517880693123e+217 },
	{ 1.000000e+233,	2.625937292600896716e+216 },
	{ 1.000000e+232,	-5.647541102052084079e+215 },
	{ 1.000000e+231,	-5.647541102052083888e+214 },
	{ 1.000000e+230,	-9.956644432600511943e+213 },
	{ 1.000000e+229,	8.161138937705571862e+211 },
	{ 1.000000e+228,	7.549087847752475275e+211 },
	{ 1.000000e+227,	-9.283347037202319948e+210 },
	{ 1.000000e+226,	3.866992716668613820e+209 },
	{ 1.000000e+225,	7.154577655136347262e+208 },
	{ 1.000000e+224,	3.045096482051680688e+207 },
	{ 1.000000e+223,	-4.660180717482069567e+206 },
	{ 1.000000e+222,	-4.660180717482070101e+205 },
	{ 1.000000e+221,	-4.660180717482069544e+204 },
	{ 1.000000e+220,	3.562757926310489022e+202 },
	{ 1.000000e+219,	3.491561111451748149e+202 },
	{ 1.000000e+218,	-8.265758834125874135e+201 },
	{ 1.000000e+217,	3.981449442517482365e+200 },
	{ 1.000000e+216,	-2.142154695804195936e+199 },
	{ 1.000000e+215,	9.339603063548950188e+198 },
	{ 1.000000e+214,	4.555537330485139746e+197 },
	{ 1.000000e+213,	1.565496247320257804e+196 },
	{ 1.000000e+212,	9.040598955232462036e+195 },
	{ 1.000000e+211,	4.368659762787334780e+194 },
	{ 1.000000e+210,	7.288621758065539072e+193 },
	{ 1.000000e+209,	-7.311188218325485628e+192 },
	{ 1.000000e+208,	1.813693016918905189e+191 },
	{ 1.000000e+207,	-3.889357755108838992e+190 },
	{ 1.000000e+206,	-3.889357755108838992e+189 },
	{ 1.000000e+205,	-1.661603547285501360e+188 },
	{ 1.000000e+204,	1.123089212493670643e+187 },
	{ 1.000000e+203,	1.123089212493670643e+186 },
	{ 1.000000e+202,	9.825254086803583029e+185 },
	{ 1.000000e+201,	-3.771878529305654999e+184 },
	{ 1.000000e+200,	3.026687778748963675e+183 },
	{ 1.000000e+199,	-9.720624048853446693e+182 },
	{ 1.000000e+198,	-1.753554156601940139e+181 },
	{ 1.000000e+197,	4.885670753607648963e+180 },
	{ 1.000000e+196,	4.885670753607648963e+179 },
	{ 1.000000e+195,	2.292223523057028076e+178 },
	{ 1.000000e+194,	5.534032561245303825e+177 },
	{ 1.000000e+193,	-6.622751331960730683e+176 },
	{ 1.000000e+192,	-4.090088020876139692e+175 },
	{ 1.000000e+191,	-7.255917159731877552e+174 },
	{ 1.000000e+190,	-7.255917159731877992e+173 },
	{ 1.000000e+189,	-2.309309130269787104e+172 },
	{ 1.000000e+188,	-2.309309130269787019e+171 },
	{ 1.000000e+187,	9.284303438781988230e+170 },
	{ 1.000000e+186,	2.038295583124628364e+169 },
	{ 1.000000e+185,	2.038295583124628532e+168 },
	{ 1.000000e+184,	-1.735666841696912925e+167 },
	{ 1.000000e+183,	5.340512704843477241e+166 },
	{ 1.000000e+182,	-6.453119872723839321e+165 },
	{ 1.000000e+181,	8.288920849235306587e+164 },
	{ 1.000000e+180,	-9.248546019891598293e+162 },
	{ 1.000000e+179,	1.954450226518486016e+162 },
	{ 1.000000e+178,	-5.243811844750628197e+161 },
	{ 1.000000e+177,	-7.448980502074320639e+159 },
	{ 1.000000e+176,	-7.448980502074319858e+158 },
	{ 1.000000e+175,	6.284654753766312753e+158 },
	{ 1.000000e+174,	-6.895756753684458388e+157 },
	{ 1.000000e+173,	-1.403918625579970616e+156 },
	{ 1.000000e+172,	-8.268716285710580522e+155 },
	{ 1.000000e+171,	4.602779327034313170e+154 },
	{ 1.000000e+170,	-3.441905430931244940e+153 },
	{ 1.000000e+169,	6.613950516525702884e+152 },
	{ 1.000000e+168,	6.613950516525702652e+151 },
	{ 1.000000e+167,	-3.860899428741951187e+150 },
	{ 1.000000e+166,	5.959272394946474605e+149 },
	{ 1.000000e+165,	1.005101065481665103e+149 },
	{ 1.000000e+164,	-1.783349948587918355e+146 },
	{ 1.000000e+163,	6.215006036188360099e+146 },
	{ 1.000000e+162,	6.215006036188360099e+145 },
	{ 1.000000e+161,	-3.774589324822814903e+144 },
	{ 1.000000e+160,	-6.528407745068226929e+142 },
	{ 1.000000e+159,	7.151530601283157561e+142 },
	{ 1.000000e+158,	4.712664546348788765e+141 },
	{ 1.000000e+157,	1.664081977680827856e+140 },
	{ 1.000000e+156,	1.664081977680827750e+139 },
	{ 1.000000e+155,	-7.176231540910168265e+137 },
	{ 1.000000e+154,	-3.694754568805822650e+137 },
	{ 1.000000e+153,	2.665969958768462622e+134 },
	{ 1.000000e+152,	-4.625108135904199522e+135 },
	{ 1.000000e+151,	-1.717753238721771919e+134 },
	{ 1.000000e+150,	1.916440382756262433e+133 },
	{ 1.000000e+149,	-4.897672657515052040e+132 },
	{ 1.000000e+148,	-4.897672657515052198e+131 },
	{ 1.000000e+147,	2.200361759434233991e+130 },
	{ 1.000000e+146,	6.636633270027537273e+129 },
	{ 1.000000e+145,	1.091293881785907977e+128 },
	{ 1.000000e+144,	-2.374543235865110597e+127 },
	{ 1.000000e+143,	-2.374543235865110537e+126 },
	{ 1.000000e+142,	-5.082228484029969099e+125 },
	{ 1.000000e+141,	-1.697621923823895943e+124 },
	{ 1.000000e+140,	-5.928380124081487212e+123 },
	{ 1.000000e+139,	-3.284156248920492522e+122 },
	{ 1.000000e+138,	-3.284156248920492706e+121 },
	{ 1.000000e+137,	-3.284156248920492476e+120 },
	{ 1.000000e+136,	-5.866406127007401066e+119 },
	{ 1.000000e+135,	3.817030915818506056e+118 },
	{ 1.000000e+134,	7.851796350329300951e+117 },
	{ 1.000000e+133,	-2.235117235947686077e+116 },
	{ 1.000000e+132,	9.170432597638723691e+114 },
	{ 1.000000e+131,	8.797444499042767883e+114 },
	{ 1.000000e+130,	-5.978307824605161274e+113 },
	{ 1.000000e+129,	1.782556435814758516e+111 },
	{ 1.000000e+128,	-7.517448691651820362e+111 },
	{ 1.000000e+127,	4.507089332150205498e+110 },
	{ 1.000000e+126,	7.513223838100711695e+109 },
	{ 1.000000e+125,	7.513223838100712113e+108 },
	{ 1.000000e+124,	5.164681255326878494e+107 },
	{ 1.000000e+123,	2.229003026859587122e+106 },
	{ 1.000000e+122,	-1.440594758724527399e+105 },
	{ 1.000000e+121,	-3.734093374714598783e+104 },
	{ 1.000000e+120,	1.999653165260579757e+103 },
	{ 1.000000e+119,	5.583244752745066693e+102 },
	{ 1.000000e+118,	3.343500010567262234e+101 },
	{ 1.000000e+117,	-5.055542772599503556e+100 },
	{ 1.000000e+116,	-1.555941612946684331e+99 },
	{ 1.000000e+115,	-1.555941612946684331e+98 },
	{ 1.000000e+114,	-1.555941612946684293e+97 },
	{ 1.000000e+113,	-1.555941612946684246e+96 },
	{ 1.000000e+112,	6.988006530736955847e+95 },
	{ 1.000000e+111,	4.318022735835818244e+94 },
	{ 1.000000e+110,	-2.356936751417025578e+93 },
	{ 1.000000e+109,	1.814912928116001926e+92 },
	{ 1.000000e+108,	-3.399899171300282744e+91 },
	{ 1.000000e+107,	3.118615952970072913e+90 },
	{ 1.000000e+106,	-9.103599905036843605e+89 },
	{ 1.000000e+105,	6.174169917471802325e+88 },
	{ 1.000000e+104,	-1.915675085734668657e+86 },
	{ 1.000000e+103,	-1.915675085734668864e+85 },
	{ 1.000000e+102,	2.295048673475466221e+85 },
	{ 1.000000e+101,	2.295048673475466135e+84 },
	{ 1.000000e+100,	-1.590289110975991792e+83 },
	{ 1.000000e+99,	3.266383119588331155e+82 },
	{ 1.000000e+98,	2.309629754856292029e+80 },
	{ 1.000000e+97,	-7.357587384771124533e+80 },
	{ 1.000000e+96,	-4.986165397190889509e+79 },
	{ 1.000000e+95,	-2.021887912715594741e+78 },
	{ 1.000000e+94,	-2.021887912715594638e+77 },
	{ 1.000000e+93,	-4.337729697461918675e+76 },
	{ 1.000000e+92,	-4.337729697461918997e+75 },
	{ 1.000000e+91,	-7.956232486128049702e+74 },
	{ 1.000000e+90,	3.351588728453609882e+73 },
	{ 1.000000e+89,	5.246334248081951113e+71 },
	{ 1.000000e+88,	4.058327554364963672e+71 },
	{ 1.000000e+87,	4.058327554364963918e+70 },
	{ 1.000000e+86,	-1.463069523067487266e+69 },
	{ 1.000000e+85,	-1.463069523067487314e+68 },
	{ 1.000000e+84,	-5.776660989811589441e+67 },
	{ 1.000000e+83,	-3.080666323096525761e+66 },
	{ 1.000000e+82,	3.659320343691134468e+65 },
	{ 1.000000e+81,	7.871812010433421235e+64 },
	{ 1.000000e+80,	-2.660986470836727449e+61 },
	{ 1.000000e+79,	3.264399249934044627e+62 },
	{ 1.000000e+78,	-8.493621433689703070e+60 },
	{ 1.000000e+77,	1.721738727445414063e+60 },
	{ 1.000000e+76,	-4.706013449590547218e+59 },
	{ 1.000000e+75,	7.346021882351880518e+58 },
	{ 1.000000e+74,	4.835181188197207515e+57 },
	{ 1.000000e+73,	1.696630320503867482e+56 },
	{ 1.000000e+72,	5.619818905120542959e+55 },
	{ 1.000000e+71,	-4.188152556421145598e+54 },
	{ 1.000000e+70,	-7.253143638152923145e+53 },
	{ 1.000000e+69,	-7.253143638152923145e+52 },
	{ 1.000000e+68,	4.719477774861832896e+51 },
	{ 1.000000e+67,	1.726322421608144052e+50 },
	{ 1.000000e+66,	5.467766613175255107e+49 },
	{ 1.000000e+65,	7.909613737163661911e+47 },
	{ 1.000000e+64,	-2.132041900945439564e+47 },
	{ 1.000000e+63,	-5.785795994272697265e+46 },
	{ 1.000000e+62,	-3.502199685943161329e+45 },
	{ 1.000000e+61,	5.061286470292598274e+44 },
	{ 1.000000e+60,	5.061286470292598472e+43 },
	{ 1.000000e+59,	2.831211950439536034e+42 },
	{ 1.000000e+58,	5.618805100255863927e+41 },
	{ 1.000000e+57,	-4.834669211555366251e+40 },
	{ 1.000000e+56,	-9.190283508143378583e+39 },
	{ 1.000000e+55,	-1.023506702040855158e+38 },
	{ 1.000000e+54,	-7.829154040459624616e+37 },
	{ 1.000000e+53,	6.779051325638372659e+35 },
	{ 1.000000e+52,	6.779051325638372290e+34 },
	{ 1.000000e+51,	6.779051325638371598e+33 },
	{ 1.000000e+50,	-7.629769841091887392e+33 },
	{ 1.000000e+49,	5.350972305245182400e+32 },
	{ 1.000000e+48,	-4.384584304507619764e+31 },
	{ 1.000000e+47,	-4.384584304507619876e+30 },
	{ 1.000000e+46,	6.860180964052978705e+28 },
	{ 1.000000e+45,	7.024271097546444878e+28 },
	{ 1.000000e+44,	-8.821361405306422641e+27 },
	{ 1.000000e+43,	-1.393721169594140991e+26 },
	{ 1.000000e+42,	-4.488571267807591679e+25 },
	{ 1.000000e+41,	-6.200086450407783195e+23 },
	{ 1.000000e+40,	-3.037860284270036669e+23 },
	{ 1.000000e+39,	6.029083362839682141e+22 },
	{ 1.000000e+38,	2.251190176543965970e+21 },
	{ 1.000000e+37,	4.612373417978788577e+20 },
	{ 1.000000e+36,	-4.242063737401796198e+19 },
	{ 1.000000e+35,	3.136633892082024448e+18 },
	{ 1.000000e+34,	5.442476901295718400e+17 },
	{ 1.000000e+33,	5.442476901295718400e+16 },
	{ 1.000000e+32,	-5.366162204393472000e+15 },
	{ 1.000000e+31,	3.641037050347520000e+14 },
	{ 1.000000e+30,	-1.988462483865600000e+13 },
	{ 1.000000e+29,	8.566849142784000000e+12 },
	{ 1.000000e+28,	4.168802631680000000e+11 },
	{ 1.000000e+27,	-1.328755507200000000e+10 },
	{ 1.000000e+26,	-4.764729344000000000e+09 },
	{ 1.000000e+25,	-9.059696640000000000e+08 },
	{ 1.000000e+24,	1.677721600000000000e+07 },
	{ 1.000000e+23,	8.388608000000000000e+06 },
	{ 1.000000e+22,	0.000000000000000000e+00 },
	{ 1.000000e+21,	0.000000000000000000e+00 },
	{ 1.000000e+20,	0.000000000000000000e+00 },
	{ 1.000000e+19,	0.000000000000000000e+00 },
	{ 1.000000e+18,	0.000000000000000000e+00 },
	{ 1.000000e+17,	0.000000000000000000e+00 },
	{ 1.000000e+16,	0.000000000000000000e+00 },
	{ 1.000000e+15,	0.000000000000000000e+00 },
	{ 1.000000e+14,	0.000000000000000000e+00 },
	{ 1.000000e+13,	0.000000000000000000e+00 },
	{ 1.000000e+12,	0.000000000000000000e+00 },
	{ 1.000000e+11,	0.000000000000000000e+00 },
	{ 1.000000e+10,	0.000000000000000000e+00 },
	{ 1.000000e+09,	0.000000000000000000e+00 },
	{ 1.000000e+08,	0.000000000000000000e+00 },
	{ 1.000000e+07,	0.000000000000000000e+00 },
	{ 1.000000e+06,	0.000000000000000000e+00 },
	{ 1.000000e+05,	0.000000000000000000e+00 },
	{ 1.000000e+04,	0.000000000000000000e+00 },
	{ 1.000000e+03,	0.000000000000000000e+00 },
	{ 1.000000e+02,	0.000000000000000000e+00 },
	{ 1.000000e+01,	0.000000000000000000e+00 },
	{ 1.000000e+00,	0.000000000000000000e+00 },
	{ 1.000000e-01,	-5.551115123125783010e-18 },
	{ 1.000000e-02,	-2.081668171172168436e-19 },
	{ 1.000000e-03,	-2.081668171172168557e-20 },
	{ 1.000000e-04,	-4.792173602385929943e-21 },
	{ 1.000000e-05,	-8.180305391403130547e-22 },
	{ 1.000000e-06,	4.525188817411374069e-23 },
	{ 1.000000e-07,	4.525188817411373922e-24 },
	{ 1.000000e-08,	-2.092256083012847109e-25 },
	{ 1.000000e-09,	-6.228159145777985254e-26 },
	{ 1.000000e-10,	-3.643219731549774344e-27 },
	{ 1.000000e-11,	6.050303071806019080e-28 },
	{ 1.000000e-12,	2.011335237074438524e-29 },
	{ 1.000000e-13,	-3.037374556340037101e-30 },
	{ 1.000000e-14,	1.180690645440101289e-32 },
	{ 1.000000e-15,	-7.770539987666107583e-32 },
	{ 1.000000e-16,	2.090221327596539779e-33 },
	{ 1.000000e-17,	-7.154242405462192144e-34 },
	{ 1.000000e-18,	-7.154242405462192572e-35 },
	{ 1.000000e-19,	2.475407316473986894e-36 },
	{ 1.000000e-20,	5.484672854579042914e-37 },
	{ 1.000000e-21,	9.246254777210362522e-38 },
	{ 1.000000e-22,	-4.859677432657087182e-39 },
	{ 1.000000e-23,	3.956530198510069291e-40 },
	{ 1.000000e-24,	7.629950044829717753e-41 },
	{ 1.000000e-25,	-3.849486974919183692e-42 },
	{ 1.000000e-26,	-3.849486974919184170e-43 },
	{ 1.000000e-27,	-3.849486974919184070e-44 },
	{ 1.000000e-28,	2.876745653839937870e-45 },
	{ 1.000000e-29,	5.679342582489572168e-46 },
	{ 1.000000e-30,	-8.333642060758598930e-47 },
	{ 1.000000e-31,	-8.333642060758597958e-48 },
	{ 1.000000e-32,	-5.596730997624190224e-49 },
	{ 1.000000e-33,	-5.596730997624190604e-50 },
	{ 1.000000e-34,	7.232539610818348498e-51 },
	{ 1.000000e-35,	-7.857545194582380514e-53 },
	{ 1.000000e-36,	5.896157255772251528e-53 },
	{ 1.000000e-37,	-6.632427322784915796e-54 },
	{ 1.000000e-38,	3.808059826012723592e-55 },
	{ 1.000000e-39,	7.070712060011985131e-56 },
	{ 1.000000e-40,	7.070712060011985584e-57 },
	{ 1.000000e-41,	-5.761291134237854167e-59 },
	{ 1.000000e-42,	-3.762312935688689794e-59 },
	{ 1.000000e-43,	-7.745042713519821150e-60 },
	{ 1.000000e-44,	4.700987842202462817e-61 },
	{ 1.000000e-45,	1.589480203271891964e-62 },
	{ 1.000000e-46,	-2.299904345391321765e-63 },
	{ 1.000000e-47,	2.561826340437695261e-64 },
	{ 1.000000e-48,	2.561826340437695345e-65 },
	{ 1.000000e-49,	6.360053438741614633e-66 },
	{ 1.000000e-50,	-7.616223705782342295e-68 },
	{ 1.000000e-51,	-7.616223705782343324e-69 },
	{ 1.000000e-52,	-7.616223705782342295e-70 },
	{ 1.000000e-53,	-3.079876214757872338e-70 },
	{ 1.000000e-54,	-3.079876214757872821e-71 },
	{ 1.000000e-55,	5.423954167728123147e-73 },
	{ 1.000000e-56,	-3.985444122640543680e-73 },
	{ 1.000000e-57,	4.504255013759498850e-74 },
	{ 1.000000e-58,	-2.570494266573869991e-75 },
	{ 1.000000e-59,	-2.570494266573869930e-76 },
	{ 1.000000e-60,	2.956653608686574324e-77 },
	{ 1.000000e-61,	-3.952281235388981376e-78 },
	{ 1.000000e-62,	-3.952281235388981376e-79 },
	{ 1.000000e-63,	-6.651083908855995172e-80 },
	{ 1.000000e-64,	3.469426116645307030e-81 },
	{ 1.000000e-65,	7.686305293937516319e-82 },
	{ 1.000000e-66,	2.415206322322254927e-83 },
	{ 1.000000e-67,	5.709643179581793251e-84 },
	{ 1.000000e-68,	-6.644495035141475923e-85 },
	{ 1.000000e-69,	3.650620143794581913e-86 },
	{ 1.000000e-70,	4.333966503770636492e-88 },
	{ 1.000000e-71,	8.476455383920859113e-88 },
	{ 1.000000e-72,	3.449543675455986564e-89 },
	{ 1.000000e-73,	3.077238576654418974e-91 },
	{ 1.000000e-74,	4.234998629903623140e-91 },
	{ 1.000000e-75,	4.234998629903623412e-92 },
	{ 1.000000e-76,	7.303182045714702338e-93 },
	{ 1.000000e-77,	7.303182045714701699e-94 },
	{ 1.000000e-78,	1.121271649074855759e-96 },
	{ 1.000000e-79,	1.121271649074855863e-97 },
	{ 1.000000e-80,	3.857468248661243988e-97 },
	{ 1.000000e-81,	3.857468248661244248e-98 },
	{ 1.000000e-82,	3.857468248661244410e-99 },
	{ 1.000000e-83,	-3.457651055545315679e-100 },
	{ 1.000000e-84,	-3.457651055545315933e-101 },
	{ 1.000000e-85,	2.257285900866059216e-102 },
	{ 1.000000e-86,	-8.458220892405268345e-103 },
	{ 1.000000e-87,	-1.761029146610688867e-104 },
	{ 1.000000e-88,	6.610460535632536565e-105 },
	{ 1.000000e-89,	-3.853901567171494935e-106 },
	{ 1.000000e-90,	5.062493089968513723e-108 },
	{ 1.000000e-91,	-2.218844988608365240e-108 },
	{ 1.000000e-92,	1.187522883398155383e-109 },
	{ 1.000000e-93,	9.703442563414457296e-110 },
	{ 1.000000e-94,	4.380992763404268896e-111 },
	{ 1.000000e-95,	1.054461638397900823e-112 },
	{ 1.000000e-96,	9.370789450913819736e-113 },
	{ 1.000000e-97,	-3.623472756142303998e-114 },
	{ 1.000000e-98,	6.122223899149788839e-115 },
	{ 1.000000e-99,	-1.999189980260288281e-116 },
	{ 1.000000e-100,	-1.999189980260288281e-117 },
	{ 1.000000e-101,	-5.171617276904849634e-118 },
	{ 1.000000e-102,	6.724985085512256320e-119 },
	{ 1.000000e-103,	4.246526260008692213e-120 },
	{ 1.000000e-104,	7.344599791888147003e-121 },
	{ 1.000000e-105,	3.472007877038828407e-122 },
	{ 1.000000e-106,	5.892377823819652194e-123 },
	{ 1.000000e-107,	-1.585470431324073925e-125 },
	{ 1.000000e-108,	-3.940375084977444795e-125 },
	{ 1.000000e-109,	7.869099673288519908e-127 },
	{ 1.000000e-110,	-5.122196348054018581e-127 },
	{ 1.000000e-111,	-8.815387795168313713e-128 },
	{ 1.000000e-112,	5.034080131510290214e-129 },
	{ 1.000000e-113,	2.148774313452247863e-130 },
	{ 1.000000e-114,	-5.064490231692858416e-131 },
	{ 1.000000e-115,	-5.064490231692858166e-132 },
	{ 1.000000e-116,	5.708726942017560559e-134 },
	{ 1.000000e-117,	-2.951229134482377772e-134 },
	{ 1.000000e-118,	1.451398151372789513e-135 },
	{ 1.000000e-119,	-1.300243902286690040e-136 },
	{ 1.000000e-120,	2.139308664787659449e-137 },
	{ 1.000000e-121,	2.139308664787659329e-138 },
	{ 1.000000e-122,	-5.922142664292847471e-139 },
	{ 1.000000e-123,	-5.922142664292846912e-140 },
	{ 1.000000e-124,	6.673875037395443799e-141 },
	{ 1.000000e-125,	-1.198636026159737932e-142 },
	{ 1.000000e-126,	5.361789860136246995e-143 },
	{ 1.000000e-127,	-2.838742497733733936e-144 },
	{ 1.000000e-128,	-5.401408859568103261e-145 },
	{ 1.000000e-129,	7.411922949603743011e-146 },
	{ 1.000000e-130,	-8.604741811861064385e-147 },
	{ 1.000000e-131,	1.405673664054439890e-148 },
	{ 1.000000e-132,	1.405673664054439933e-149 },
	{ 1.000000e-133,	-6.414963426504548053e-150 },
	{ 1.000000e-134,	-3.971014335704864578e-151 },
	{ 1.000000e-135,	-3.971014335704864748e-152 },
	{ 1.000000e-136,	-1.523438813303585576e-154 },
	{ 1.000000e-137,	2.234325152653707766e-154 },
	{ 1.000000e-138,	-6.715683724786540160e-155 },
	{ 1.000000e-139,	-2.986513359186437306e-156 },
	{ 1.000000e-140,	1.674949597813692102e-157 },
	{ 1.000000e-141,	-4.151879098436469092e-158 },
	{ 1.000000e-142,	-4.151879098436469295e-159 },
	{ 1.000000e-143,	4.952540739454407825e-160 },
	{ 1.000000e-144,	4.952540739454407667e-161 },
	{ 1.000000e-145,	8.508954738630531443e-162 },
	{ 1.000000e-146,	-2.604839008794855481e-163 },
	{ 1.000000e-147,	2.952057864917838382e-164 },
	{ 1.000000e-148,	6.425118410988271757e-165 },
	{ 1.000000e-149,	2.083792728400229858e-166 },
	{ 1.000000e-150,	-6.295358232172964237e-168 },
	{ 1.000000e-151,	6.153785555826519421e-168 },
	{ 1.000000e-152,	-6.564942029880634994e-169 },
	{ 1.000000e-153,	-3.915207116191644540e-170 },
	{ 1.000000e-154,	2.709130168030831503e-171 },
	{ 1.000000e-155,	-1.431080634608215966e-172 },
	{ 1.000000e-156,	-4.018712386257620994e-173 },
	{ 1.000000e-157,	5.684906682427646782e-174 },
	{ 1.000000e-158,	-6.444617153428937489e-175 },
	{ 1.000000e-159,	1.136335243981427681e-176 },
	{ 1.000000e-160,	1.136335243981427725e-177 },
	{ 1.000000e-161,	-2.812077463003137395e-178 },
	{ 1.000000e-162,	4.591196362592922204e-179 },
	{ 1.000000e-163,	7.675893789924613703e-180 },
	{ 1.000000e-164,	3.820022005759999543e-181 },
	{ 1.000000e-165,	-9.998177244457686588e-183 },
	{ 1.000000e-166,	-4.012217555824373639e-183 },
	{ 1.000000e-167,	-2.467177666011174334e-185 },
	{ 1.000000e-168,	-4.953592503130188139e-185 },
	{ 1.000000e-169,	-2.011795792799518887e-186 },
	{ 1.000000e-170,	1.665450095113817423e-187 },
	{ 1.000000e-171,	1.665450095113817487e-188 },
	{ 1.000000e-172,	-4.080246604750770577e-189 },
	{ 1.000000e-173,	-4.080246604750770677e-190 },
	{ 1.000000e-174,	4.085789420184387951e-192 },
	{ 1.000000e-175,	4.085789420184388146e-193 },
	{ 1.000000e-176,	4.085789420184388146e-194 },
	{ 1.000000e-177,	4.792197640035244894e-194 },
	{ 1.000000e-178,	4.792197640035244742e-195 },
	{ 1.000000e-179,	-2.057206575616014662e-196 },
	{ 1.000000e-180,	-2.057206575616014662e-197 },
	{ 1.000000e-181,	-4.732755097354788053e-198 },
	{ 1.000000e-182,	-4.732755097354787867e-199 },
	{ 1.000000e-183,	-5.522105321379546765e-201 },
	{ 1.000000e-184,	-5.777891238658996019e-201 },
	{ 1.000000e-185,	7.542096444923057046e-203 },
	{ 1.000000e-186,	8.919335748431433483e-203 },
	{ 1.000000e-187,	-1.287071881492476028e-204 },
	{ 1.000000e-188,	5.091932887209967018e-205 },
	{ 1.000000e-189,	-6.868701054107114024e-206 },
	{ 1.000000e-190,	-1.885103578558330118e-207 },
	{ 1.000000e-191,	-1.885103578558330205e-208 },
	{ 1.000000e-192,	-9.671974634103305058e-209 },
	{ 1.000000e-193,	-4.805180224387695640e-210 },
	{ 1.000000e-194,	-1.763433718315439838e-211 },
	{ 1.000000e-195,	-9.367799983496079132e-212 },
	{ 1.000000e-196,	-4.615071067758179837e-213 },
	{ 1.000000e-197,	1.325840076914194777e-214 },
	{ 1.000000e-198,	8.751979007754662425e-215 },
	{ 1.000000e-199,	1.789973760091724198e-216 },
	{ 1.000000e-200,	1.789973760091724077e-217 },
	{ 1.000000e-201,	5.416018159916171171e-218 },
	{ 1.000000e-202,	-3.649092839644947067e-219 },
	{ 1.000000e-203,	-3.649092839644947067e-220 },
	{ 1.000000e-204,	-1.080338554413850956e-222 },
	{ 1.000000e-205,	-1.080338554413850841e-223 },
	{ 1.000000e-206,	-2.874486186850417807e-223 },
	{ 1.000000e-207,	7.499710055933455072e-224 },
	{ 1.000000e-208,	-9.790617015372999087e-225 },
	{ 1.000000e-209,	-4.387389805589732612e-226 },
	{ 1.000000e-210,	-4.387389805589732612e-227 },
	{ 1.000000e-211,	-8.608661063232909897e-228 },
	{ 1.000000e-212,	4.582811616902018972e-229 },
	{ 1.000000e-213,	4.582811616902019155e-230 },
	{ 1.000000e-214,	8.705146829444184930e-231 },
	{ 1.000000e-215,	-4.177150709750081830e-232 },
	{ 1.000000e-216,	-4.177150709750082366e-233 },
	{ 1.000000e-217,	-8.202868690748290237e-234 },
	{ 1.000000e-218,	-3.170721214500530119e-235 },
	{ 1.000000e-219,	-3.170721214500529857e-236 },
	{ 1.000000e-220,	7.606440013180328441e-238 },
	{ 1.000000e-221,	-1.696459258568569049e-238 },
	{ 1.000000e-222,	-4.767838333426821244e-239 },
	{ 1.000000e-223,	2.910609353718809138e-240 },
	{ 1.000000e-224,	-1.888420450747209784e-241 },
	{ 1.000000e-225,	4.110366804835314035e-242 },
	{ 1.000000e-226,	7.859608839574391006e-243 },
	{ 1.000000e-227,	5.516332567862468419e-244 },
	{ 1.000000e-228,	-3.270953451057244613e-245 },
	{ 1.000000e-229,	-6.932322625607124670e-246 },
	{ 1.000000e-230,	-4.643966891513449762e-247 },
	{ 1.000000e-231,	1.076922443720738305e-248 },
	{ 1.000000e-232,	-2.498633390800628939e-249 },
	{ 1.000000e-233,	4.205533798926934891e-250 },
	{ 1.000000e-234,	4.205533798926934891e-251 },
	{ 1.000000e-235,	4.205533798926934697e-252 },
	{ 1.000000e-236,	-4.523850562697497656e-253 },
	{ 1.000000e-237,	9.320146633177728298e-255 },
	{ 1.000000e-238,	9.320146633177728062e-256 },
	{ 1.000000e-239,	-7.592774752331086440e-256 },
	{ 1.000000e-240,	3.063212017229987840e-257 },
	{ 1.000000e-241,	3.063212017229987562e-258 },
	{ 1.000000e-242,	3.063212017229987562e-259 },
	{ 1.000000e-243,	4.616527473176159842e-261 },
	{ 1.000000e-244,	6.965550922098544975e-261 },
	{ 1.000000e-245,	6.965550922098544749e-262 },
	{ 1.000000e-246,	4.424965697574744679e-263 },
	{ 1.000000e-247,	-1.926497363734756420e-264 },
	{ 1.000000e-248,	2.043167049583681740e-265 },
	{ 1.000000e-249,	-5.399953725388390154e-266 },
	{ 1.000000e-250,	-5.399953725388389982e-267 },
	{ 1.000000e-251,	-1.523328321757102663e-268 },
	{ 1.000000e-252,	5.745344310051561161e-269 },
	{ 1.000000e-253,	-6.369110076296211879e-270 },
	{ 1.000000e-254,	8.773957906638504842e-271 },
	{ 1.000000e-255,	-6.904595826956931908e-273 },
	{ 1.000000e-256,	2.267170882721243669e-273 },
	{ 1.000000e-257,	2.267170882721243669e-274 },
	{ 1.000000e-258,	4.577819683828225398e-275 },
	{ 1.000000e-259,	-6.975424321706684210e-276 },
	{ 1.000000e-260,	3.855741933482293648e-277 },
	{ 1.000000e-261,	1.599248963651256552e-278 },
	{ 1.000000e-262,	-1.221367248637539543e-279 },
	{ 1.000000e-263,	-1.221367248637539494e-280 },
	{ 1.000000e-264,	-1.221367248637539647e-281 },
	{ 1.000000e-265,	1.533140771175737943e-282 },
	{ 1.000000e-266,	1.533140771175737895e-283 },
	{ 1.000000e-267,	1.533140771175738074e-284 },
	{ 1.000000e-268,	4.223090009274641634e-285 },
	{ 1.000000e-269,	4.223090009274641634e-286 },
	{ 1.000000e-270,	-4.183001359784432924e-287 },
	{ 1.000000e-271,	3.697709298708449474e-288 },
	{ 1.000000e-272,	6.981338739747150474e-289 },
	{ 1.000000e-273,	-9.436808465446354751e-290 },
	{ 1.000000e-274,	3.389869038611071740e-291 },
	{ 1.000000e-275,	6.596538414625427829e-292 },
	{ 1.000000e-276,	-9.436808465446354618e-293 },
	{ 1.000000e-277,	3.089243784609725523e-294 },
	{ 1.000000e-278,	6.220756847123745836e-295 },
	{ 1.000000e-279,	-5.522417137303829470e-296 },
	{ 1.000000e-280,	4.263561183052483059e-297 },
	{ 1.000000e-281,	-1.852675267170212272e-298 },
	{ 1.000000e-282,	-1.852675267170212378e-299 },
	{ 1.000000e-283,	5.314789322934508480e-300 },
	{ 1.000000e-284,	-3.644541414696392675e-301 },
	{ 1.000000e-285,	-7.377595888709267777e-302 },
	{ 1.000000e-286,	-5.044436842451220838e-303 },
	{ 1.000000e-287,	-2.127988034628661760e-304 },
	{ 1.000000e-288,	-5.773549044406860911e-305 },
	{ 1.000000e-289,	-1.216597782184112068e-306 },
	{ 1.000000e-290,	-6.912786859962547924e-307 },
	{ 1.000000e-291,	3.767567660872018813e-308 },
};
